@@ -113,13 +113,15 @@ public abstract class Axis {
      * @param  ticks  tickmark array
      * @param  title  axis label text, may be null
      * @param  captioner  text positioning object
+     * @param  tickLook  tick drawing style
      * @param  orient  axis orientation code
      * @param  invert  whether to reverse sense of axis 
      * @param  g   graphics context
      */
-    public void drawLabels( Tick[] ticks, String title, Captioner captioner,
+    public void drawLabels( Tick[] ticks, String title,
+                            Captioner captioner, TickLook tickLook,
                             Orientation orient, boolean invert, Graphics g ) {
-        calculateLabels( ticks, title, captioner, orient, invert, g );
+        calculateLabels( ticks, title, captioner, tickLook, orient, invert, g );
     }
 
     /**
@@ -137,7 +139,8 @@ public abstract class Axis {
     public Rectangle getLabelBounds( Tick[] ticks, String title,
                                      Captioner captioner, Orientation orient,
                                      boolean invert ) {
-        return calculateLabels( ticks, title, captioner, orient, invert, null );
+        return calculateLabels( ticks, title, captioner, TickLook.NONE,
+                                orient, invert, null );
     }
 
     /**
@@ -146,14 +149,16 @@ public abstract class Axis {
      * @param  ticks  tickmark array
      * @param  title  axis label text, may be null
      * @param  captioner  text positioning object
+     * @param  tickLook  tick drawing style
      * @param  orient  axis orientation code
      * @param  invert  whether to reverse sense of axis 
      * @param  graphics context, or null if no painting is required
      * @return   bounding box for all annotations
      */
     private Rectangle calculateLabels( Tick[] ticks, String title,
-                                       Captioner captioner, Orientation orient,
-                                       boolean invert, Graphics g ) {
+                                       Captioner captioner, TickLook tickLook,
+                                       Orientation orient, boolean invert,
+                                       Graphics g ) {
         boolean hasGraphics = g != null;
         Graphics2D g2 = hasGraphics ? (Graphics2D) g : null;
         AffineTransform trans0 = hasGraphics ? g2.getTransform() : null;
@@ -169,23 +174,26 @@ public abstract class Axis {
         Rectangle tickBounds = new Rectangle();
 
         /* Place ticks. */
-        int tickUnit = orient.isDown() ? -2 : +2;
+        AffineTransform upTrans =
+            AffineTransform.getScaleInstance( 1, orient.isDown() ? -1 : +1 );
         for ( int it = 0; it < ticks.length; it++ ) {
             Tick tick = ticks[ it ];
             Caption label = tick.getLabel();
+            boolean hasText =
+                label != null && label.toText().trim().length() > 0;
             int gx = (int) dataToGraphics( tick.getValue() );
             double tx = invert ? ghi_ - gx : gx - glo_;
             AffineTransform tTrans =
                 AffineTransform.getTranslateInstance( tx, 0 );
-            Rectangle cbounds = label == null
-                              ? null
-                              : captioner.getCaptionBounds( label );
-            AffineTransform oTrans =
-                label == null ? null
-                              : orient.captionTransform( cbounds, cpad );
+            Rectangle cbounds = hasText
+                              ? captioner.getCaptionBounds( label )
+                              : null;
+            AffineTransform oTrans = hasText
+                                   ? orient.captionTransform( cbounds, cpad )
+                                   : null;
 
             /* Update bounding box for tick labels. */
-            if ( label != null ) {
+            if ( hasText ) {
                 Rectangle box = combineTrans( tTrans, oTrans )
                                .createTransformedShape( cbounds ).getBounds();
                 tickBounds.add( box );
@@ -193,14 +201,17 @@ public abstract class Axis {
 
             /* If we are drawing, draw now. */
             if ( hasGraphics ) {
-                g2.setTransform( combineTrans( trans0, tTrans ) );
+                g2.setTransform( combineTrans( trans0, tTrans, upTrans ) );
                 if ( label != null ) {
-                    g2.drawLine( 0, -tickUnit, 0, tickUnit );
-                    g2.setTransform( combineTrans( trans0, tTrans, oTrans ) );
-                    captioner.drawCaption( label, g2 );
+                    tickLook.drawMajor( g2 );
+                    if ( hasText ) {
+                        g2.setTransform( combineTrans( trans0, tTrans,
+                                                       oTrans ) );
+                        captioner.drawCaption( label, g2 );
+                    }
                 }
                 else {
-                    g2.drawLine( 0, 0, 0, tickUnit );
+                    tickLook.drawMinor( g2 );
                 }
                 g2.setTransform( trans0 );
             }
