@@ -20,6 +20,7 @@ import uk.ac.starlink.task.Parameter;
 import uk.ac.starlink.task.TaskException;
 import uk.ac.starlink.ttools.Stilts;
 import uk.ac.starlink.ttools.filter.SelectFilter;
+import uk.ac.starlink.ttools.plot2.DataGeom;
 import uk.ac.starlink.ttools.plot2.GangerFactory;
 import uk.ac.starlink.ttools.plot2.PlotType;
 import uk.ac.starlink.ttools.plot2.PlotUtil;
@@ -221,6 +222,7 @@ public class StiltsPlot {
 
         /* Per-zone settings. */
         if ( hasIndependentZones || nz == 1 ) {
+            assert ! ( plotSpec.getPlotType() instanceof MatrixPlotType );
             for ( int iz = 0; iz < nz; iz++ ) {
                 ConfigMap zoneConfig = zoneConfigs[ iz ];
                 List<Setting> settings = new ArrayList<>();
@@ -286,6 +288,9 @@ public class StiltsPlot {
             lsettings.addAll( createInputTableSettings( lspec, namer ) );
             lsettings.add( null );
 
+            /* DataGeom setting, if any. */
+            lsettings.addAll( createGeomSettings( lspec, task ) );
+
             /* Input data coordinate settings, if any. */
             lsettings.addAll( createCoordSettings( lspec ) );
             lsettings.add( null );
@@ -779,6 +784,36 @@ public class StiltsPlot {
         return settings;
     }
 
+    /**
+     * Returns a list of settings corresponding to the DataGeom selected
+     * for a given layer specification.
+     *
+     * @param   lspec  layer specification
+     * @param   task   task on behalf of which layer is working
+     * @return   list of zero or more setting objects
+     */
+    private static List<Setting> createGeomSettings( LayerSpec lspec,
+                                                     AbstractPlot2Task task ) {
+        PlotContext<?,?> context = task instanceof TypedPlot2Task
+                                 ? ((TypedPlot2Task) task).getPlotContext()
+                                 : null;
+        Parameter<?> geomParam = context == null
+                               ? null
+                               : context.getGeomParameter( "" );
+        List<Setting> settings = new ArrayList<>();
+        if ( geomParam != null &&
+             DataGeom.class.isAssignableFrom( geomParam.getValueClass() ) ) {
+            @SuppressWarnings("unchecked")
+            Parameter<DataGeom> typedGeomParam =
+                (Parameter<DataGeom>) geomParam;
+            DataGeom geom = lspec.getDataGeom();
+            if ( geom != null ) {
+                settings.add( createParamSetting( typedGeomParam, geom ) );
+            }
+        }
+        return settings;
+    }
+
     /**
      * Returns the key's value if it is specified in the given config map,
      * or null if it is not.  Note this differs from just calling
@@ -1045,6 +1080,23 @@ public class StiltsPlot {
             settings.addAll( settingMap.values() );
             settings.add( null );
         }
+
+        /* Add global items from the profile keys, apart from the X/Y-specific
+         * ones which we have taken care of in the previous step.
+         * By special arrangement these are not extracted in other parts
+         * of the configuration in the special case of the Matrix Plot. */
+        List<ConfigKey<?>> profileKeyList =
+            new ArrayList<>( Arrays.asList( surfFact.getProfileKeys() ) );
+        for ( XyKeyPair<?> xyk : xyKeyPairs ) {
+            profileKeyList.remove( xyk.getKeyX() );
+            profileKeyList.remove( xyk.getKeyY() );
+        }
+        ConfigKey<?>[] profileKeys =
+            profileKeyList.toArray( new ConfigKey<?>[ 0 ] );
+        settings.add( null );
+        settings.addAll( getConfigSettings( globalConfig, profileKeys ) );
+
+        /* Return the result. */
         return settings;
     }
 
