@@ -116,6 +116,7 @@ public class TablePipeTest extends TableTestCase {
         StarTable withSize = apply( "addcol -before 1"
                                   + " -ucd PHYS.SIZE"
                                   + " -utype tc:size"
+                                  + " -xtype tc:Chubba"
                                   + " -desc 'Not important'"
                                   + " -units parsec" 
                                   + " SIZE 99.f" );
@@ -123,6 +124,7 @@ public class TablePipeTest extends TableTestCase {
         assertEquals( "SIZE", sizeInfo.getName() );
         assertEquals( "PHYS.SIZE", sizeInfo.getUCD() );
         assertEquals( "tc:size", sizeInfo.getUtype() );
+        assertEquals( "tc:Chubba", sizeInfo.getXtype() );
         assertEquals( "parsec", sizeInfo.getUnitString() );
         assertEquals( Float.class, sizeInfo.getContentClass() );
 
@@ -822,7 +824,7 @@ public class TablePipeTest extends TableTestCase {
 
         ColumnInfo info = apply( "replacecol"
                                + " -ucd UCD -units UNITS -desc DESCRIPTION"
-                               + " -utype UTYPE"
+                               + " -utype UTYPE -xtype XTYPE"
                                + " -name NAME"
                                + " b '\"Message\"'" ).getColumnInfo( 1 );
         assertEquals( "NAME", info.getName() );
@@ -830,6 +832,7 @@ public class TablePipeTest extends TableTestCase {
         assertEquals( "UNITS", info.getUnitString() );
         assertEquals( "DESCRIPTION", info.getDescription() );
         assertEquals( "UTYPE", info.getUtype() );
+        assertEquals( "XTYPE", info.getXtype() );
         assertEquals( String.class, info.getContentClass() );
     }
 
